#include "usersmanager.h"


#include "stssettings.h"

#include <unistd.h>


UsersManager::UsersManager(const UsersPwdList& users,
                           const IconList& icons,
                           StsSettings* stsSettings,
                           QObject* parent) :
    QObject(parent),
    Manager("users"),
    m_stsSettings(stsSettings)
{
    const auto defaultIcon = icons.value("", QIcon());
    const auto hostname = getHostname();

    foreach (const auto& user, users) {
        UserData data;
        data.username = user.username;
        data.hostname = hostname;
        data.icon = icons.value(user.username, defaultIcon);
        m_users << data;
    }
}

UsersManager::~UsersManager()
{
}

const UsersData UsersManager::users() const
{
    return m_users;
}

const QString UsersManager::defaultUsername() const
{
    if (!m_stsSettings) {
        return QString();
    }

    return m_stsSettings->getDefaultUsername();
}

void UsersManager::saveDefaultUsername(const QString& username) const
{
    if (!m_stsSettings) {
        return;
    }

    m_stsSettings->saveDefaultUsername(username);
}

const QString UsersManager::getHostname()
{
    char buf[256];
    buf[sizeof(buf) - 1] = '\0';
    if (gethostname(buf, sizeof(buf) - 1)) {
        return "localhost";
    } else {
        return QString::fromLocal8Bit(buf);
    }
}
